print\_ctf
==============

Print recent CTF contests sourced by CTFTime.org
(from https://ctftime.org/calendar/)

THIS PACKAGE IS UNOFFICIAL

Usage
------

```
$ print_ctf --weeks=4
```

History
-------

* 1.0.2: Fixed module directory
* 1.0.1: Fixed installing script
* 1.0.0: First release

